/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import {NgModule} from '@angular/core';
import {CommonModule} from '@angular/common';
import {ReactiveFormsModule} from "@angular/forms";
import {NgbModule} from '@ng-bootstrap/ng-bootstrap';
import {HttpClientModule} from "@angular/common/http";
import {SharedModule} from "../shared/shared.module";

import {ResultTypeService} from "./services/result-type.service";
import {FiltersComponent} from './filters/filters.component';
import {FilterService} from "./services/filter.service";

import {DatesComponent} from './filters/dates/dates.component';
import {FrequenciesComponent} from './filters/frequencies/frequencies.component';
import {SourcePositionComponent} from './filters/source-position/source-position.component';
import {TelescopesComponent} from './filters/telescopes/telescopes.component';
import {ConfigurationsComponent} from './filters/configurations/configurations.component';
import {ReceiversComponent} from './filters/receivers/receivers.component';
import {PolarizationsComponent} from './filters/polarizations/polarizations.component';
import {TextSearchComponent} from './filters/text-search/text-search.component';

import {ObservationResultsComponent} from './observation-results/observation-results.component';
import {ProjectResultsComponent} from './project-results/project-results.component';
import {ImageResultsComponent} from './image-results/image-results.component';

import {ObservationDetailsComponent} from "./observation-details/observation-details.component";

import {ArchiveSearchRoutingModule} from './archive-search-routing.module';
import {ArchiveSearchComponent} from './archive-search.component';
import {SelectedFiltersComponent} from './selected-filters/selected-filters.component';
import {SaveFiltersComponent} from './selected-filters/save-filters/save-filters.component';
import {LoadFiltersComponent} from './selected-filters/load-filters/load-filters.component';
import {ProjectComponent} from './filters/project/project.component';
import {FrequencyPipe} from './pipes/frequency.pipe';
import {CoordFormatPipe} from './pipes/coord-format.pipe';
import {ProjectDetailsComponent} from './project-details/project-details.component';
import {AatHeaderComponent} from './aat-header/aat-header.component';
import {SearchComponent} from './search/search.component';

@NgModule({
  declarations: [
    FiltersComponent,
    DatesComponent,
    FrequenciesComponent,
    SourcePositionComponent,
    TelescopesComponent,
    ConfigurationsComponent,
    ReceiversComponent,
    PolarizationsComponent,
    ObservationResultsComponent,
    ProjectResultsComponent,
    ImageResultsComponent,
    ArchiveSearchComponent,
    SelectedFiltersComponent,
    SaveFiltersComponent,
    LoadFiltersComponent,
    ProjectComponent,
    TextSearchComponent,
    ObservationDetailsComponent,
    FrequencyPipe,
    CoordFormatPipe,
    ProjectDetailsComponent,
    AatHeaderComponent,
    SearchComponent
  ],
  providers: [ ResultTypeService, FilterService ],
  entryComponents: [
    DatesComponent,
    FrequenciesComponent,
    SourcePositionComponent,
    TelescopesComponent,
    ConfigurationsComponent,
    ReceiversComponent,
    PolarizationsComponent,
    TextSearchComponent,
    ProjectComponent,
    SaveFiltersComponent,
    LoadFiltersComponent
  ],
  imports: [
    SharedModule,
    CommonModule,
    ReactiveFormsModule,
    NgbModule,
    ArchiveSearchRoutingModule,
    HttpClientModule
  ]
})
export class ArchiveSearchModule { }
