"""add ingest seci workflow

Revision ID: 1b534e426ace
Revises: c98733cfe926
Create Date: 2022-04-20 15:47:17.087002

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "1b534e426ace"
down_revision = "c98733cfe926"
branch_labels = None
depends_on = None


condor_content = """executable = ingest_seci.sh
arguments = {{cal_spl}} {{cache_path}}

output = ingest.out
error = ingest.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
SPOOL_DIR = {{spool_dir}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/ingest_envoy, nraorsync://$(SBIN_PATH)/ingest, nraorsync://$(SBIN_PATH)/seci-product-collector.sh, nraorsync://$(SPOOL_DIR)/aux_image_metadata.json
+WantIOProxy = True

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue

"""

script_content = """#!/bin/sh
set -o errexit

./ingest_envoy --seci $1 $2

"""

aux_content = """{
  "project_code": "{{projectCode}}",
  "band_code": "{{bands}}",
  "configurations": "{{configurations}}",
  "starttime": null,
  "endtime": null,
  "exposure_time": null,
  "rms_noise": null,
  "image_tags": "",
  "product_tags": "",
  "collection_name": "",
  "calibration_level": 2
}

"""


def upgrade():
    op.execute(
        """
        INSERT INTO workflows (workflow_name, uses_casa) VALUES ('ingest_seci', false)
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('ingest_seci.condor', E'{condor_content}','ingest_seci')
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('ingest_seci.sh', E'{script_content}','ingest_seci')
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('aux_image_metadata.json', E'{aux_content}','ingest_seci')
        """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflows WHERE workflow_name='ingest_seci'
        """
    )
    op.execute(
        """
        DELETE FROM workflow_templates WHERE workflow_name='ingest_seci'
        """
    )
